==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/he/base.php <==
<?php

return [
    'Administration' => 'ניהול',
    'Default' => 'ברירת מחדל',
    'Groups' => 'קבוצות',
    'Modules' => 'מודולים',
    'Spaces' => 'אזורים',
    'Users' => 'משתמשים',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module </strong> administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'About' => '',
    'Admin' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Approval' => '',
    'Authentication' => '',
    'Back to overview' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Basic' => '',
    'Caching' => '',
    'Cronjobs' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Design' => '',
    'Files' => '',
    'General' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logging' => '',
    'Logs' => '',
    'Mailing' => '',
    'Notifications' => '',
    'OEmbed' => '',
    'OEmbed providers' => '',
    'Open documentation' => '',
    'Pending user registrations' => '',
    'People' => '',
    'Permissions' => '',
    'Proxy' => '',
    'Self test' => '',
    'Settings' => '',
    'Sign up' => '',
    'Statistics' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'User posts' => '',
    'Userprofiles' => '',
];

==> humhub-1.11.3.tar.gz: humhub-1.11.3/protected/humhub/modules/admin/messages/he/base.php <==
<?php

return [
    'Administration' => 'ניהול',
    'Default' => 'ברירת מחדל',
    'Groups' => 'קבוצות',
    'Modules' => 'מודולים',
    'Spaces' => 'אזורים',
    'Users' => 'משתמשים',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module</strong> Administration' => '',
    '<strong>Warning</strong> incomplete setup!' => '',
    'About' => '',
    'Activate' => '',
    'Add Licence Key' => '',
    'Admin' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Approval' => '',
    'Authentication' => '',
    'Back to overview' => '',
    'Back to user overview' => '',
    'Base URL needs to begin with http:// or https://' => '',
    'Basic' => '',
    'Caching' => '',
    'Configure' => '',
    'Cronjobs' => '',
    'Deactivate' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Design' => '',
    'Files' => '',
    'General' => '',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => '',
    'Information' => '',
    'Invalid user state: {state}' => '',
    'Invite' => '',
    'Invited by' => '',
    'Logging' => '',
    'Logs' => '',
    'Mailing' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'Notifications' => '',
    'OEmbed' => '',
    'OEmbed providers' => '',
    'Open documentation' => '',
    'Pending user registrations' => '',
    'People' => '',
    'Permissions' => '',
    'Proxy' => '',
    'Search' => '',
    'Search...' => '',
    'Self test' => '',
    'Set as default' => '',
    'Settings' => '',
    'Sign up' => '',
    'Statistics' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'Uninstall' => '',
    'User not found!' => '',
    'Userprofiles' => '',
];
